@@ -18,15 +18,25 @@
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
+import gi
+gi.require_version('Gedit', '3.0')
+gi.require_version('Gtk', '3.0')
 from gi.repository import GObject, Gio, Gedit, Gtk
 import os
-
 from .schemer import GUI
 
-class WindowActivatable(GObject.Object, Gedit.WindowActivatable):
+try:
+    import gettext
+    gettext.bindtextdomain('gedit-plugins')
+    gettext.textdomain('gedit-plugins')
+    _ = gettext.gettext
+except:
+    _ = lambda s: s
 
-  window = GObject.property(type=Gedit.Window)
+
+class AppActivatable(GObject.Object, Gedit.AppActivatable):
+
+  app = GObject.Property(type=Gedit.App)
 
   def __init__(self):
     GObject.Object.__init__(self)
@@ -34,14 +44,16 @@ class WindowActivatable(GObject.Object, Gedit.WindowActivatable):
   def do_activate(self):
     action = Gio.SimpleAction(name="schemer")
     action.connect('activate', self.open_dialog)
-    self.window.add_action(action)
+    self.app.add_action(action)
 
-    self.menu = self.extend_gear_menu("ext9")
-    item = Gio.MenuItem.new(_("Color Scheme Editor"), "win.schemer")
-    self.menu.append_menu_item(item)
-
-  def open_dialog(self, action, parameter, data=None):
-    schemer.GUI(Gedit.App, os.path.join(self.plugin_info.get_data_dir(), 'ui'))
+    self.menu_ext = self.extend_menu("preferences-section")
+    item = Gio.MenuItem.new(_("Color Scheme Editor"), "app.schemer")
+    self.menu_ext.append_menu_item(item)
 
   def do_deactivate(self):
-    self.window.remove_action("schemer")
+    self.app.remove_action("schemer")
+    self.menu_ext = None
+
+  def open_dialog(self, action, parameter, data=None):
+    GUI(Gedit.App, os.path.join(self.plugin_info.get_data_dir(), 'ui'))
+
